==> ejc-middlemeasurement-impl-3.0.0-20230404.070319-438-sources.jar: com/ejianc/business/middlemeasurement/excel/ExceldesignsubcontractnodeController.java <==
package com.ejianc.business.middlemeasurement.excel;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.NumberUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.middlemeasurement.bean.DesignsubcontractnodedetailEntity;
import com.ejianc.business.middlemeasurement.service.IDesignsubcontractnodeService;
import com.ejianc.business.middlemeasurement.service.IDesignsubcontractnodedetailService;
import com.ejianc.business.middlemeasurement.vo.DesignsubcontractnodedetailVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.*;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping("designsubcontractnodeExport")
public class ExceldesignsubcontractnodeController {

    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IDesignsubcontractnodedetailService detailService;
    @Autowired
    private IDesignsubcontractnodeService service;

    /**
     * 导入模板下载
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/downloadDesignsubcontractnode", method = RequestMethod.POST)
    @ResponseBody
    public void downloadConsdrawbudget(HttpServletRequest request, HttpServletResponse response) {
        ImportTemplate.initialize(response);
        ImportTemplate.templetdownload(request, "designsubcontractnode-import.xlsx", "设计分包中间计量-导入模板");
    }

    /**
     * excel导入
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelImportDesignsubcontractnode", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Object> excelImportInterimsettlement(HttpServletRequest request, HttpServletResponse response, Long contract, Long projectId,String monthStr) throws ParseException {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        List<DesignsubcontractnodedetailVO> successList = new ArrayList<>();
        List<DesignsubcontractnodedetailVO> errorList = new ArrayList<>();
        DateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");
        boolean isFailed = false;
        MultipartFile mf = null;
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            mf = entity.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }
        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {
            List<List<String>> result = ExcelReader.readExcel(mf);

            if (result != null && result.size() > 0) {

                for (int i = 2; i < result.size(); i++) {
                    StringBuilder errorsMsgBuilder = new StringBuilder();

                    DesignsubcontractnodedetailVO designsubcontractnodedetailVO = new DesignsubcontractnodedetailVO();
                    List<String> datas = result.get(i);
                    designsubcontractnodedetailVO.setSort(String.valueOf(IdWorker.getId()));//id
                    //设置子表合同id
                    designsubcontractnodedetailVO.setContract(contract);
                    //设置子表项目id
                    designsubcontractnodedetailVO.setProjectId(projectId);


                    String projectName = datas.get(0);//项目名称
                    String projectCharacteristics = datas.get(1);//项目特征
                    String measuringUnit = datas.get(2);//*计量单位

                    String exTaxUnitLastAudit = datas.get(3);//*除税单价
                    String inTaxUnitLastAudit = datas.get(4);//*含税单价
                    String completeThisAudit = datas.get(5);//*完成量(本期 )
                    String remarks = datas.get(6);//备注

                    designsubcontractnodedetailVO.setId(IdWorker.getId());
                    designsubcontractnodedetailVO.setProjectCharacteristics(projectCharacteristics); // 项目特征
                    designsubcontractnodedetailVO.setRemarks(remarks); // 备注
                    if (StringUtils.isBlank(projectName)) {
                        designsubcontractnodedetailVO.setErrorMsg("项目名称不能为空！");
                        errorsMsgBuilder.append("项目名称不能为空");
                    } else {
                        designsubcontractnodedetailVO.setProjectName(projectName); // 项目名称
                    }

                    if (StringUtils.isBlank(measuringUnit)) {
                        designsubcontractnodedetailVO.setErrorMsg("计量单位不能为空！");
                        errorsMsgBuilder.append("计量单位不能为空!");
                    } else {
                        designsubcontractnodedetailVO.setMeasuringUnit(measuringUnit); // 计量单位
                    }

                    if (StringUtils.isBlank(exTaxUnitLastAudit)) {
                        designsubcontractnodedetailVO.setErrorMsg("除税单价不能为空！");
                        errorsMsgBuilder.append("除税单价不能为空");
                    } else {
                        if (!NumberUtil.isNumber(exTaxUnitLastAudit)) {
                            designsubcontractnodedetailVO.setErrorMsg("除税单价格式错误！");
                            errorsMsgBuilder.append("除税单价格式错误");
                        } else {
                            designsubcontractnodedetailVO.setExTaxUnitLastAudit(new BigDecimal(exTaxUnitLastAudit)); //  完成量（本期申报）
                        }
                    }
                    if (StringUtils.isBlank(inTaxUnitLastAudit)) {
                        designsubcontractnodedetailVO.setErrorMsg("含税单价不能为空！");
                        errorsMsgBuilder.append("含税单价不能为空");
                    } else {
                        if (!NumberUtil.isNumber(inTaxUnitLastAudit)) {
                            designsubcontractnodedetailVO.setErrorMsg("含税单价格式错误！");
                            errorsMsgBuilder.append("含税单价格式错误");
                        } else {
                            designsubcontractnodedetailVO.setInTaxUnitLastAudit(new BigDecimal(inTaxUnitLastAudit)); //  含税单价
                        }
                    }


                    if (StringUtils.isBlank(completeThisAudit)) {
                        designsubcontractnodedetailVO.setErrorMsg("(本期)完成量不能为空！");
                        errorsMsgBuilder.append("(本期)完成量不能为空！");
                    } else {
                        if (!NumberUtil.isNumber(completeThisAudit)) {
                            designsubcontractnodedetailVO.setErrorMsg("(本期)完成量格式错误！");
                            errorsMsgBuilder.append("(本期)完成量格式错误！");
                        } else {
                            designsubcontractnodedetailVO.setCompleteThisAudit(new BigDecimal(completeThisAudit)); // 完成量（本期审核）
                        }
                    }



                    DesignsubcontractnodedetailVO vo = service.queryDetailHistory(designsubcontractnodedetailVO.getContract(),designsubcontractnodedetailVO.getProjectName(),designsubcontractnodedetailVO.getExTaxUnitLastAudit(),designsubcontractnodedetailVO.getInTaxUnitLastAudit());
                    if(vo != null){
                        //上期
                        designsubcontractnodedetailVO.setCompleteLastAudit(vo.getCompleteThisAudit() == null ? new BigDecimal("0"):vo.getCompleteThisAudit());
                        designsubcontractnodedetailVO.setExTaxTotalLastAudit(vo.getExTaxTotalThisAudit() == null ? new BigDecimal("0"):vo.getExTaxTotalThisAudit());
                        designsubcontractnodedetailVO.setInTaxTotalLastAudit(vo.getInTaxTotalThisAudit() == null ? new BigDecimal("0"):vo.getInTaxTotalThisAudit());
                    }
                    //exTaxTotalThisAudit; // 含税合价（本期审核）
                    designsubcontractnodedetailVO.setExTaxTotalThisAudit(ComputeUtil.safeMultiply(designsubcontractnodedetailVO.getExTaxUnitLastAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getExTaxUnitLastAudit(),designsubcontractnodedetailVO.getCompleteThisAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getCompleteThisAudit()));
                    // inTaxTotalThisAudit; // 含税合价（本期审核）
                    designsubcontractnodedetailVO.setInTaxTotalThisAudit(ComputeUtil.safeMultiply(designsubcontractnodedetailVO.getCompleteThisAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getCompleteThisAudit(),designsubcontractnodedetailVO.getInTaxUnitLastAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getInTaxUnitLastAudit()));
                    //累计
                    designsubcontractnodedetailVO.setCompleteCumulativeAudit(ComputeUtil.safeAdd(designsubcontractnodedetailVO.getCompleteLastAudit() == null ? new BigDecimal(0):designsubcontractnodedetailVO.getCompleteLastAudit(),designsubcontractnodedetailVO.getCompleteThisAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getCompleteThisAudit()));
                    designsubcontractnodedetailVO.setExTaxTotalCumulativeAudit(ComputeUtil.safeAdd(designsubcontractnodedetailVO.getExTaxTotalLastAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getExTaxTotalLastAudit(),designsubcontractnodedetailVO.getExTaxTotalThisAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getExTaxTotalThisAudit()));
                    designsubcontractnodedetailVO.setInTaxTotalCumulativeAudit(ComputeUtil.safeAdd(designsubcontractnodedetailVO.getInTaxTotalLastAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getInTaxTotalLastAudit(),designsubcontractnodedetailVO.getInTaxTotalThisAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getInTaxTotalThisAudit()));


                    if (errorsMsgBuilder.length() > 0) {
                        errorList.add(designsubcontractnodedetailVO);
                    } else {
                        successList.add(designsubcontractnodedetailVO);
                    }
                }
            }
        }
        JSONObject json = new JSONObject();
        json.put("successNum", successList.size());
        json.put("successList", successList);
        json.put("errorList", errorList);
        json.put("errorNum", errorList.size());
        return CommonResponse.success(json);
    }

    /**
     * excel导出数据库数据
     *
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelExportDesignsubcontractnodeFromDatabase", method = RequestMethod.POST)
    @ResponseBody
    public void excelExportConsdrawbudgetFromDatabase(@RequestBody DesignsubcontractnodedetailVO
                                                              detailVo, HttpServletResponse response) {
        QueryWrapper<DesignsubcontractnodedetailEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mid", detailVo.getId());
        queryWrapper.eq("dr", 0);
        List<DesignsubcontractnodedetailEntity> list = detailService.list(queryWrapper);
        List<DesignsubcontractnodedetailVO> designsubcontractnodedetailVOList = BeanMapper.mapList(list, DesignsubcontractnodedetailVO.class);
        if (designsubcontractnodedetailVOList != null && designsubcontractnodedetailVOList.size() > 0) {
            for (int i = 0; i < designsubcontractnodedetailVOList.size(); i++) {
                DesignsubcontractnodedetailVO designsubcontractnodedetailVO = designsubcontractnodedetailVOList.get(i);
                designsubcontractnodedetailVO.setSort(String.valueOf(i + 1));
            }
        }
        Map<String, Object> beans = new HashMap<String, Object>();
        beans.put("records", designsubcontractnodedetailVOList);
        ExcelExport.getInstance().export("designsubcontractnode-export.xlsx", beans, response);
    }

    /**
     * excel导出页面数据
     *
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelExportDesignsubcontractnodeFromPage", method = RequestMethod.POST)
    @ResponseBody
    public void excelExportConsdrawbudgetFromPage
    (@RequestBody List<DesignsubcontractnodedetailVO> list, HttpServletResponse response) {

        if (list != null && list.size() > 0) {
            for (int i = 0; i < list.size(); i++) {
                DesignsubcontractnodedetailVO designsubcontractnodedetailVO = list.get(i);
                designsubcontractnodedetailVO.setSort(String.valueOf(i + 1));
            }
        }
        Map<String, Object> beans = new HashMap<String, Object>();
        beans.put("records", list);
        ExcelExport.getInstance().export("designsubcontractnode-export.xlsx", beans, response);
    }


}

==> ejc-middlemeasurement-impl-3.0.0-20230830.034615-488-sources.jar: com/ejianc/business/middlemeasurement/excel/ExceldesignsubcontractnodeController.java <==
package com.ejianc.business.middlemeasurement.excel;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.NumberUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.middlemeasurement.bean.DesignsubcontractnodedetailEntity;
import com.ejianc.business.middlemeasurement.service.IDesignsubcontractnodeService;
import com.ejianc.business.middlemeasurement.service.IDesignsubcontractnodedetailService;
import com.ejianc.business.middlemeasurement.vo.DesignsubcontractnodedetailVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.*;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping("designsubcontractnodeExport")
public class ExceldesignsubcontractnodeController {

    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IDesignsubcontractnodedetailService detailService;
    @Autowired
    private IDesignsubcontractnodeService service;

    /**
     * 导入模板下载
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/downloadDesignsubcontractnode", method = RequestMethod.POST)
    @ResponseBody
    public void downloadConsdrawbudget(HttpServletRequest request, HttpServletResponse response) {
        ImportTemplate.initialize(response);
        ImportTemplate.templetdownload(request, "designsubcontractnode-import.xlsx", "设计分包中间计量-导入模板");
    }

    /**
     * excel导入
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelImportDesignsubcontractnode", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Object> excelImportInterimsettlement(HttpServletRequest request, HttpServletResponse response, Long contract, Long projectId,String monthStr) throws ParseException {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        List<DesignsubcontractnodedetailVO> successList = new ArrayList<>();
        List<DesignsubcontractnodedetailVO> errorList = new ArrayList<>();
        DateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");
        boolean isFailed = false;
        MultipartFile mf = null;
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            mf = entity.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }
        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {
            List<List<String>> result = ExcelReader.readExcel(mf);

            if (result != null && result.size() > 0) {

                for (int i = 2; i < result.size(); i++) {
                    StringBuilder errorsMsgBuilder = new StringBuilder();

                    DesignsubcontractnodedetailVO designsubcontractnodedetailVO = new DesignsubcontractnodedetailVO();
                    List<String> datas = result.get(i);
                    designsubcontractnodedetailVO.setSort(String.valueOf(IdWorker.getId()));//id
                    //设置子表合同id
                    designsubcontractnodedetailVO.setContract(contract);
                    //设置子表项目id
                    designsubcontractnodedetailVO.setProjectId(projectId);


                    String projectName = datas.get(0);//项目名称
                    String projectCharacteristics = datas.get(1);//项目特征
                    String measuringUnit = datas.get(2);//*计量单位

                    String exTaxUnitLastAudit = datas.get(3);//*除税单价
                    String inTaxUnitLastAudit = datas.get(4);//*含税单价
                    String completeThisAudit = datas.get(5);//*完成量(本期 )
                    String remarks = datas.get(6);//备注

                    designsubcontractnodedetailVO.setId(IdWorker.getId());
                    designsubcontractnodedetailVO.setProjectCharacteristics(projectCharacteristics); // 项目特征
                    designsubcontractnodedetailVO.setRemarks(remarks); // 备注
                    if (StringUtils.isBlank(projectName)) {
                        designsubcontractnodedetailVO.setErrorMsg("项目名称不能为空！");
                        errorsMsgBuilder.append("项目名称不能为空");
                    } else {
                        designsubcontractnodedetailVO.setProjectName(projectName); // 项目名称
                    }

                    if (StringUtils.isBlank(projectCharacteristics)) {
                        designsubcontractnodedetailVO.setErrorMsg("项目特征不能为空！");
                        errorsMsgBuilder.append("项目特征不能为空");
                    } else {
                        designsubcontractnodedetailVO.setProjectCharacteristics(projectCharacteristics); // 项目特征
                    }

                    if (StringUtils.isBlank(measuringUnit)) {
                        designsubcontractnodedetailVO.setErrorMsg("计量单位不能为空！");
                        errorsMsgBuilder.append("计量单位不能为空!");
                    } else {
                        designsubcontractnodedetailVO.setMeasuringUnit(measuringUnit); // 计量单位
                    }

                    if (StringUtils.isBlank(exTaxUnitLastAudit)) {
                        designsubcontractnodedetailVO.setErrorMsg("除税单价不能为空！");
                        errorsMsgBuilder.append("除税单价不能为空");
                    } else {
                        if (!NumberUtil.isNumber(exTaxUnitLastAudit)) {
                            designsubcontractnodedetailVO.setErrorMsg("除税单价格式错误！");
                            errorsMsgBuilder.append("除税单价格式错误");
                        } else {
                            designsubcontractnodedetailVO.setExTaxUnitLastAudit(new BigDecimal(exTaxUnitLastAudit)); //  完成量（本期申报）
                        }
                    }
                    if (StringUtils.isBlank(inTaxUnitLastAudit)) {
                        designsubcontractnodedetailVO.setErrorMsg("含税单价不能为空！");
                        errorsMsgBuilder.append("含税单价不能为空");
                    } else {
                        if (!NumberUtil.isNumber(inTaxUnitLastAudit)) {
                            designsubcontractnodedetailVO.setErrorMsg("含税单价格式错误！");
                            errorsMsgBuilder.append("含税单价格式错误");
                        } else {
                            designsubcontractnodedetailVO.setInTaxUnitLastAudit(new BigDecimal(inTaxUnitLastAudit)); //  含税单价
                        }
                    }


                    if (StringUtils.isBlank(completeThisAudit)) {
                        designsubcontractnodedetailVO.setErrorMsg("(本期)完成量不能为空！");
                        errorsMsgBuilder.append("(本期)完成量不能为空！");
                    } else {
                        if (!NumberUtil.isNumber(completeThisAudit)) {
                            designsubcontractnodedetailVO.setErrorMsg("(本期)完成量格式错误！");
                            errorsMsgBuilder.append("(本期)完成量格式错误！");
                        } else {
                            designsubcontractnodedetailVO.setCompleteThisAudit(new BigDecimal(completeThisAudit)); // 完成量（本期审核）
                        }
                    }



                    DesignsubcontractnodedetailVO vo = service.queryDetailHistory(designsubcontractnodedetailVO.getContract(),designsubcontractnodedetailVO.getProjectName(),designsubcontractnodedetailVO.getExTaxUnitLastAudit(),designsubcontractnodedetailVO.getInTaxUnitLastAudit());
                    if(vo != null){
                        //上期
                        designsubcontractnodedetailVO.setCompleteLastAudit(vo.getCompleteThisAudit() == null ? new BigDecimal("0"):vo.getCompleteThisAudit());
                        designsubcontractnodedetailVO.setExTaxTotalLastAudit(vo.getExTaxTotalThisAudit() == null ? new BigDecimal("0"):vo.getExTaxTotalThisAudit());
                        designsubcontractnodedetailVO.setInTaxTotalLastAudit(vo.getInTaxTotalThisAudit() == null ? new BigDecimal("0"):vo.getInTaxTotalThisAudit());
                    }
                    //exTaxTotalThisAudit; // 含税合价（本期审核）
                    designsubcontractnodedetailVO.setExTaxTotalThisAudit(ComputeUtil.safeMultiply(designsubcontractnodedetailVO.getExTaxUnitLastAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getExTaxUnitLastAudit(),designsubcontractnodedetailVO.getCompleteThisAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getCompleteThisAudit()));
                    // inTaxTotalThisAudit; // 含税合价（本期审核）
                    designsubcontractnodedetailVO.setInTaxTotalThisAudit(ComputeUtil.safeMultiply(designsubcontractnodedetailVO.getCompleteThisAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getCompleteThisAudit(),designsubcontractnodedetailVO.getInTaxUnitLastAudit()== null ? new BigDecimal("0"):designsubcontractnodedetailVO.getInTaxUnitLastAudit()));
                    //累计
                    designsubcontractnodedetailVO.setCompleteCumulativeAudit(ComputeUtil.safeAdd(designsubcontractnodedetailVO.getCompleteLastAudit() == null ? new BigDecimal(0):designsubcontractnodedetailVO.getCompleteLastAudit(),designsubcontractnodedetailVO.getCompleteThisAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getCompleteThisAudit()));
                    designsubcontractnodedetailVO.setExTaxTotalCumulativeAudit(ComputeUtil.safeAdd(designsubcontractnodedetailVO.getExTaxTotalLastAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getExTaxTotalLastAudit(),designsubcontractnodedetailVO.getExTaxTotalThisAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getExTaxTotalThisAudit()));
                    designsubcontractnodedetailVO.setInTaxTotalCumulativeAudit(ComputeUtil.safeAdd(designsubcontractnodedetailVO.getInTaxTotalLastAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getInTaxTotalLastAudit(),designsubcontractnodedetailVO.getInTaxTotalThisAudit()== null ? new BigDecimal(0):designsubcontractnodedetailVO.getInTaxTotalThisAudit()));


                    if (errorsMsgBuilder.length() > 0) {
                        errorList.add(designsubcontractnodedetailVO);
                    } else {
                        successList.add(designsubcontractnodedetailVO);
                    }
                }
            }
        }
        JSONObject json = new JSONObject();
        json.put("successNum", successList.size());
        json.put("successList", successList);
        json.put("errorList", errorList);
        json.put("errorNum", errorList.size());
        return CommonResponse.success(json);
    }

    /**
     * excel导出数据库数据
     *
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelExportDesignsubcontractnodeFromDatabase", method = RequestMethod.POST)
    @ResponseBody
    public void excelExportConsdrawbudgetFromDatabase(@RequestBody DesignsubcontractnodedetailVO
                                                              detailVo, HttpServletResponse response) {
        QueryWrapper<DesignsubcontractnodedetailEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mid", detailVo.getId());
        queryWrapper.eq("dr", 0);
        List<DesignsubcontractnodedetailEntity> list = detailService.list(queryWrapper);
        List<DesignsubcontractnodedetailVO> designsubcontractnodedetailVOList = BeanMapper.mapList(list, DesignsubcontractnodedetailVO.class);
        if (designsubcontractnodedetailVOList != null && designsubcontractnodedetailVOList.size() > 0) {
            for (int i = 0; i < designsubcontractnodedetailVOList.size(); i++) {
                DesignsubcontractnodedetailVO designsubcontractnodedetailVO = designsubcontractnodedetailVOList.get(i);
                designsubcontractnodedetailVO.setSort(String.valueOf(i + 1));
            }
        }
        Map<String, Object> beans = new HashMap<String, Object>();
        beans.put("records", designsubcontractnodedetailVOList);
        ExcelExport.getInstance().export("designsubcontractnode-export.xlsx", beans, response);
    }

    /**
     * excel导出页面数据
     *
     * @param response
     * @return
     */
    @RequestMapping(value = "/excelExportDesignsubcontractnodeFromPage", method = RequestMethod.POST)
    @ResponseBody
    public void excelExportConsdrawbudgetFromPage
    (@RequestBody List<DesignsubcontractnodedetailVO> list, HttpServletResponse response) {

        if (list != null && list.size() > 0) {
            for (int i = 0; i < list.size(); i++) {
                DesignsubcontractnodedetailVO designsubcontractnodedetailVO = list.get(i);
                designsubcontractnodedetailVO.setSort(String.valueOf(i + 1));
            }
        }
        Map<String, Object> beans = new HashMap<String, Object>();
        beans.put("records", list);
        ExcelExport.getInstance().export("designsubcontractnode-export.xlsx", beans, response);
    }


}
